#Happy new year
* ##usage 
```python
pip3 install -r requirements.txt
```
```python
* importing script
  from Akshay_grpi import new_grp
* running sript
  new_grp()
```
#Developing AbsGarden
* To install new-year script, along with the tools you need to develop
   and run tests, run the following
  in your virtualenv.
```bash
$ pip install -e .[dev]
```
